@@ -4,7 +4,8 @@ import unittest
 import doctest
 import trytond.tests.test_tryton
 from trytond.tests.test_tryton import ModuleTestCase
-from trytond.tests.test_tryton import doctest_setup, doctest_teardown
+from trytond.tests.test_tryton import (doctest_setup, doctest_teardown,
+    doctest_checker)
 
 
 class SaleTestCase(ModuleTestCase):
@@ -17,5 +18,6 @@ def suite():
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(SaleTestCase))
     suite.addTests(doctest.DocFileSuite('scenario_sale.rst',
             setUp=doctest_setup, tearDown=doctest_teardown, encoding='utf-8',
-            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE,
+            checker=doctest_checker))
     return suite
